#
# spec file for package heaptrack
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.26.0
# Needed for Leap, see boo#468748
%global __requires_exclude GLIBC_PRIVATE
%bcond_without released
Name:           heaptrack
Version:        1.4.0
Release:        bp155.1.6
Summary:        Heap Memory Allocation Profiler
License:        LGPL-2.1-or-later
URL:            https://apps.kde.org/heaptrack/
Source0:        https://download.kde.org/stable/heaptrack/%{version}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/heaptrack/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        heaptrack.keyring
%endif
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-build-with-gcc-13-by-including-cstdint.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Add-missing-include.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-Return-early-when-__libc_dlopen_mode-is-detected.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  libboost_container-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libdwarf-devel
BuildRequires:  libunwind-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  cmake(KChart) >= 2.6.0
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5ThreadWeaver)
BuildRequires:  cmake(Qt5Core) >= 5.10.0
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(libzstd)
Suggests:       heaptrack-gui

%description
A memory profiler for Linux, tracking heap allocations.

%package devel
Summary:        Development files for the Heaptrack API
Requires:       %{name} = %{version}

%description devel
This package contains files needed to develop for the Heaptrack
API.

%package gui
Summary:        GUI Frontend for Heaptrack
Requires:       %{name} = %{version}

%description gui
A Qt5/KF5 based GUI for Heaptrack.

%lang_package

%prep
%autosetup -p1

# Disable building tests, they're not used and post-build-checks trips over it
sed -i"" '/add_subdirectory(tests)/d' CMakeLists.txt

%build
%if "%{_lib}" == "lib64"
extra_opts="-DLIB_SUFFIX=64"
%endif

%cmake_kf5 -d build -- $extra_opts

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

# Fixup desktop file
%suse_update_desktop_file org.kde.heaptrack Development Profiling

%files
%license LICENSES/*
%doc README.md
%{_kf5_bindir}/heaptrack
%{_kf5_bindir}/heaptrack_print
%{_libdir}/heaptrack/

%files devel
%license LICENSES/*
%{_includedir}/heaptrack_api.h

%files gui
%{_kf5_bindir}/heaptrack_gui
%{_kf5_applicationsdir}/org.kde.heaptrack.desktop
%{_kf5_appstreamdir}/org.kde.heaptrack.appdata.xml
%dir %{_kf5_iconsdir}/hicolor/*
%dir %{_kf5_iconsdir}/hicolor/*/*
%{_kf5_iconsdir}/*/*/*/*.*

%files lang -f %{name}.lang

%changelog
* Thu Feb 23 2023 Christophe Marin <christophe@krop.fr>
- Try another way to ignore the GLIBC_PRIVATE requirement
* Wed Feb 22 2023 Christophe Marin <christophe@krop.fr>
- Add upstream change:
  * 0001-Return-early-when-__libc_dlopen_mode-is-detected.patch
- Define _filter_GLIBC_PRIVATE to fix installation on Leap
* Tue Feb  7 2023 Christophe Marin <christophe@krop.fr>
- Add GCC 13 and boost 1.81 compatibility patches:
  * 0001-Fix-build-with-gcc-13-by-including-cstdint.patch
  * 0001-Add-missing-include.patch
* Sun Nov 27 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.4.0
  * Pass client exit code in heaptrack.sh
  * Leverage non-deprecated mallinfo2
  * Add support for the mimalloc allocator
  * Explicitly encode which hooks are required and which are
    optional
  * Make mi_* symbols truly optional by usig weak symbols for them
  * Prevent malloc from disappearing in inlining example
  * handle calling heaptrack_stop() without debuginfo
  * Ensure we don't try to overwrite invalid tables
  * Make elf_symbol_table a view of const Elf::Sym
  * Ensure we don't read outside the string table for symbol names
  * Silence -Wuse-after-free for realloc call
* Sun Dec 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 1.3.0:
  * New features:
    + Allocations can be filtered by time ranges
    + Support for suppression files, including the
    __lsan_default_suppressions API
  * Fixed bugs:
    + Fails to build on CentOS 7.0 (kde#441125)
    + Crash when filtering on a time range (kde#441132)
    + Heaptrack produces impossible/incorrect stack traces (kde#439897)
    + ERROR: failed to lock heaptrack output file (kde#408547)
    + Attaching to running process generates empty file (kde#394520)
    + heaptrack launch script help text shows wrong option name for --output-file (kde#439307)
    + Can the output file take hostname into account? (kde#435195)
    + Heaptrack GUI crash when opening a zst file (kde#427970)
  * More details on https://invent.kde.org/sdk/heaptrack/-/releases/v1.3.0
- Use %%autosetup
* Sun Jan 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add quotes to text comparison to fix build with rpm 4.16.
* Sat Sep  5 2020 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 1.2.0, a bugfix release.
- Removed Fix-compile-on-32bit.patch as it was added upstream.
* Mon Aug 31 2020 Christophe Giboudeaux <christophe@krop.fr>
- Fix the plugins installation directory.
* Wed Jan 29 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Enable zstd support
* Wed May 23 2018 wbauer@tmo.at
- Add Fix-compile-on-32bit.patch to make it build on 32bit
  (kde#394330)
- Don't install office-chart-area icon from breeze to hicolor
  anymore, heaptrack comes with its own application icon now
- Mark license files as %%license instead of %%doc
- Install README.md as well, it contains instructions on how to use
  it
* Wed May 23 2018 fabian@ritter-vogt.de
- Update to version 1.1.0:
  * Stability and performance improvements
  * When extended debug information is available, stack traces now include inlined frames.
  * Split debug information in separate files is now supported.
  * Compressed debug information is properly handled.
  * The embedded flamegraph view is now searchable.
  * More details available on https://www.kdab.com/heaptrack-v1-1-0-release/
- Remove patches, now upstream:
  * fix-build.patch
* Sat Sep  2 2017 wbauer@tmo.at
- Add fix-build.patch to fix build with glibc 2.26 in Factory
  (kde#383889)
* Wed Apr 19 2017 fabian@ritter-vogt.de
- Initial commit
